import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { Song } from './song.entity';
import { CreateSongDto } from './dto/create-song.dto';
import { UpdateSongDto } from './dto/update-song.dto';

@Injectable()
export class SongService {
  constructor(
    @InjectRepository(Song)
    private songRepository: Repository<Song>
  ) {}

  findAll(): Promise<Song[]> {
    return this.songRepository.find();
  }

  findOneById(id: number): Promise<Song | null> {
    return this.songRepository.findOneBy({ id: id });
  }

  async create(createSongDto: CreateSongDto): Promise<number> {
    const song = this.songRepository.create({
      title: createSongDto.title,
      duration: createSongDto.duration
    });
    const savedSong = await this.songRepository.save(song);
    return savedSong.id;
  }

  async update(updateSongDto: UpdateSongDto): Promise<string> {
    const song = this.songRepository.findOneBy({ id: updateSongDto.id });
    if (!song)
      return "Song not found";

    await this.songRepository.update({ id: updateSongDto.id }, {
      title: updateSongDto.title,
      duration: updateSongDto.duration
    });
    return "Song updated successfully";
  }

  async remove(id: number): Promise<void> {
    await this.songRepository.delete(id);
  }

}
