'use client';

import { FormEvent, useState, useEffect } from 'react';
import Link from 'next/link';
import { Album } from '@/entities/album.entity';
import { createAlbum } from '@/app/actions';
import { useRouter } from 'next/navigation';

export default function Page() {
  const [albums, setAlbums] = useState<Album[]>([]);
  const router = useRouter();

  useEffect(() => {
    async function fetchAlbums() {
      const response = await fetch('https://api.anatid.net/album');
      const data = await response.json();
      setAlbums(data);
    }
    fetchAlbums();
  }, []);

  if (!albums) return <div>Loading...</div>

  async function onSubmit(event: FormEvent<HTMLFormElement>) {
    event.preventDefault();

    const formData = new FormData(event.currentTarget);
    const response = await createAlbum(formData);

    await response.json();
    router.refresh();
  }

  return (
    <div className="container">
      <table className="u-full-width">
        <thead>
          <tr>
            <th>Title</th>
            <th>Artist</th>
            <th>Genre</th>
          </tr>
        </thead>
        <tbody>
        {albums.map((album: Album) => (
          <tr key={album.id}>
            <td>
              <Link
                href={{
                  pathname: `/album/${album.id}`
                }}>{album.title}
              </Link>
            </td>
            <td>
              {album.artist}
            </td>
            <td>
              {album.genre}
            </td>
          </tr>
        ))}
        </tbody>
      </table>
      <form onSubmit={onSubmit}>
        <div className="row">
          <div className="six columns">
            <label for="album-title">Album Title</label><input type="text" name="title" id="album-title" />
          </div>
          <div className="six columns">
            <label for="album-artist">Artist</label><input type="text" name="artist" id="album-artist" />
          </div>
          <div className="six columns">
            <label for="album-genre">Genre</label><input type="text" name="genre" id="album-genre" />
          </div>
          <div className="six columns">
            <button type="submit">Create</button>
          </div>
        </div>
      </form>
    </div>
  );
}
